# WikiNet
This repository contains code for analysis used in [Ju et al. (2020)](https://arxiv.org/abs/2010.08381).

See [documentation](https://wikinet.readthedocs.io/en/latest/) to get started.

## Other options
* `gensim` added a [`WikiCorpus`](https://radimrehurek.com/gensim/corpora/wikicorpus.html#module-gensim.corpora.wikicorpus) class that parses through Wikipedia dumps.

## To-do

* fix dependency issue with `dionysus` and `python`
